@@ -215,16 +215,16 @@ def correct_homework_three_question_two(Yield_Substrate, Yield_Ethanol, newYxs,
             #Help-option was not used
             if hq2tgl == 0:
                 solcode = "".join((str(rndint),str(rndint*(RQ**4)+matricnb),str(hq2tgl),"0",str(RQ))) #I had some issues with the boolean, so I'm currently working with a version that in doubt tosses it out
-                print("Here's your code!\n\n"+solcode"\n\nPlease upload it in the designated Moodle-Task.")                                                                                                  
+                print("Here's your code!\n\n"+solcode+"\n\nPlease upload it in the designated Moodle-Task.")                                                                                                  
             #Help-option was used                                                                                              
             elif hq2tgl == 1:
                 solcode = "".join((str(rndint),str(rndint*(RQ**4)+matricnb),str(hq2tgl),"0",str(RQ)))
-                print("Here's your code!\n\n"+solcode"\n\nPlease upload it in the designated Moodle-Task.")                                                                                                   
+                print("Here's your code!\n\n"+solcode+"\n\nPlease upload it in the designated Moodle-Task.")                                                                                                   
             #In case somehing went wrong with the boolean.
             else:
                 solcode = "".join((str(rndint),str(rndint*(RQ**4)+matricnb),"0",str(RQ)))
                 print("Solution right but something in the function went wrong.\nAnyway... ")
-                print("Here's your code!\n\n"+solcode"\n\nPlease upload it in the designated Moodle-Task.")  
+                print("Here's your code!\n\n"+solcode+"\n\nPlease upload it in the designated Moodle-Task.")  
         
         #If the solution was not correct, the students can try again
         elif round(Yxs,2) == Yield_Substrate and round(Yxe,2) != Yield_Ethanol:
